#ifndef CIRCULAR_BUFFER_H_
#define CIRCULAR_BUFFER_H_

#include <stdbool.h>
#include <stdint.h>

#define CIRCULAR_BUFFER_SIZE 256

/**
 * @member an index of the first element.
 * @member a number of stored elements.
 * @member data buffer.
 */
typedef struct
{
	uint8_t start;
	uint8_t size;
	uint8_t data[CIRCULAR_BUFFER_SIZE];
} CircularBuffer;

/**
 * @brief Attempt to push a given value into a given buffer.
 *
 * @param a buffer.
 * @param the value that will be pushed.
 * @returns true, if the value was successfully pushed.
 */
bool circular_buffer_push(CircularBuffer* buffer, uint8_t value);

/**
 * @brief Attempt to pop a value from a given buffer.
 *
 * @param buffer.
 * @param a value, if succesfully popped, zero otherwise.
 * @returns true, if the value was successfully popped.
 */
bool circular_buffer_pop(CircularBuffer* buffer, uint8_t* value);

#endif /* CIRCULAR_BUFFER_H_ */
