#ifndef MATRIX_BUFFER_H_
#define MATRIX_BUFFER_H_

#include <stdint.h>
#include <stdbool.h>

#define MATRIX_BUFFER_ROWS 8
#define MATRIX_BUFFER_COLUMNS 128

/**
 * @member number of stored elements.
 * @member data buffer.
 */
typedef struct
{
	uint8_t size;
	uint8_t data[MATRIX_BUFFER_COLUMNS];
} MatrixRow;

/**
 * @member rows.
 */
typedef struct
{
	MatrixRow rows[MATRIX_BUFFER_ROWS];
} MatrixBuffer;

/**
 * @brief Attempt to push a given value into a row.
 *
 * @param row.
 * @param value.
 * @returns true, if value was pushed, false otherwise.
 */
bool matrix_row_push(MatrixRow* row, uint8_t value);

/**
 * @brief Find a following row after a given row.
 *
 * @param buffer.
 * @param row.
 * @returns a following row.
 */
MatrixRow* matrix_buffer_next_row(MatrixBuffer* buffer, MatrixRow* row);

#endif /* MATRIX_BUFFER_H_ */
